@@ -1,12 +1,7 @@
 package Dist::Zilla::PluginBundle::FLORA;
-BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::AUTHORITY = 'cpan:FLORA';
-}
-BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.14';
-}
+our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Build your distributions like FLORA does
-
+$Dist::Zilla::PluginBundle::FLORA::VERSION = '0.15';
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -292,7 +287,6 @@ method configure {
         MetaJSON
         PkgVersion
         PodSyntaxTests
-        NoTabsTests
     ));
 
     $self->add_plugins('PodCoverageTests')
@@ -311,9 +305,13 @@ method configure {
             authority   => $self->authority,
             do_metadata => 1,
         }],
-        [EOLTests => {
+        ['Test::EOL' => {
+            ':version' => '0.14',
             trailing_whitespace => !$self->disable_trailing_whitespace_tests,
         }],
+        ['Test::NoTabs' => {
+            ':version' => '0.09',
+        }],
     );
 
 
@@ -328,16 +326,20 @@ method configure {
     $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
 }
 
-with 'Dist::Zilla::Role::PluginBundle::Easy';
+with
+    'Dist::Zilla::Role::PluginBundle::Easy',
+    'Dist::Zilla::Role::PluginBundle::PluginRemover' => { -version => '0.103' },
+    'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
 __PACKAGE__->meta->make_immutable;
 
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -358,16 +360,15 @@ distributions.
 
 It is roughly equivalent to:
 
-  [@Filter]
-  bundle = @Basic
+  [@Basic]
 
   [MetaConfig]
   [MetaJSON]
   [PkgVersion]
   [PodSyntaxTests]
   [PodCoverageTests]
-  [NoTabsTests]
-  [EOLTests]
+  [Test::NoTabs]
+  [Test::EOL]
 
   [MetaResources]
   repository.type   = git
@@ -392,10 +393,9 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Florian Ragwitz.
+This software is copyright (c) 2015 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
